@@ -3,7 +3,6 @@
 #
 
 import numpy as np
-import warnings
 
 examples = """
 
@@ -43,17 +42,11 @@ class Experiment:
     ----------
     operating_conditions : list
         List of operating conditions
-    parameters : dict
-        Dictionary of parameters to use for this experiment, replacing default
-        parameters as appropriate
     period : string, optional
         Period (1/frequency) at which to record outputs. Default is 1 minute. Can be
         overwritten by individual operating conditions.
     termination : list, optional
         List of conditions under which to terminate the experiment. Default is None.
-    use_simulation_setup_type : str
-        Whether to use the "new" (default) or "old" simulation set-up type. "new" is
-        faster at simulating individual steps but has higher set-up overhead
     drive_cycles : dict
         Dictionary of drive cycles to use for this experiment.
     cccv_handling : str, optional
@@ -66,32 +59,14 @@ class Experiment:
     def __init__(
         self,
         operating_conditions,
-        parameters=None,
         period="1 minute",
         termination=None,
-        use_simulation_setup_type="new",
         drive_cycles={},
         cccv_handling="two-step",
     ):
         if cccv_handling not in ["two-step", "ode"]:
             raise ValueError("cccv_handling should be either 'two-step' or 'ode'")
         self.cccv_handling = cccv_handling
-        # Deprecations
-        if parameters is not None:
-            warnings.simplefilter("always", DeprecationWarning)
-            warnings.warn(
-                "'parameters' as an input to the Experiment class will soon be "
-                "deprecated. Please open an issue if you are using this feature.",
-                DeprecationWarning,
-            )
-        if use_simulation_setup_type == "old":
-            warnings.simplefilter("always", DeprecationWarning)
-            warnings.warn(
-                "'old' simulation setup type for the Experiment class will soon be "
-                "deprecated. Use 'new' instead. Please open an issue if this gives an "
-                "error or unexpected results.",
-                DeprecationWarning,
-            )
 
         self.period = self.convert_time_to_seconds(period.split())
         operating_conditions_cycles = []
@@ -147,15 +122,9 @@ class Experiment:
         self.operating_conditions, self.events = self.read_operating_conditions(
             operating_conditions, drive_cycles
         )
-        parameters = parameters or {}
-        if isinstance(parameters, dict):
-            self.parameters = parameters
-        else:
-            raise TypeError("experimental parameters should be a dictionary")
 
         self.termination_string = termination
         self.termination = self.read_termination(termination)
-        self.use_simulation_setup_type = use_simulation_setup_type
 
     def __str__(self):
         return str(self.operating_conditions_strings)
